@@ -1,4 +1,4 @@
-from python_framework.api.src.service.flask.FlaskManager import Repository
+from python_framework.api.src.annotation.RepositoryAnnotation import Repository
 from python_framework.api.src.model import ActuatorHealth
 
 @Repository(model = ActuatorHealth.ActuatorHealth)
